@@ -1,20 +1,10 @@
 """这个模块用于为开发者提供一站式的导入体验."""
 
 from . import GraiaMiraiApplication
-from .logger import (
-    AbstractLogger,
-    LoggingLogger
-)
+from .logger import AbstractLogger, LoggingLogger
 from .event.dispatcher import MessageChainCatcher
-from .event.lifecycle import (
-    ApplicationLaunched,
-    ApplicationShutdowned
-)
-from .event.messages import (
-    FriendMessage,
-    GroupMessage,
-    TempMessage
-)
+from .event.lifecycle import ApplicationLaunched, ApplicationShutdowned
+from .event.messages import FriendMessage, GroupMessage, TempMessage
 from .event.mirai import (
     BotOnlineEvent,
     BotOfflineEventActive,
@@ -25,18 +15,14 @@ from .event.mirai import (
     BotMuteEvent,
     BotUnmuteEvent,
     BotJoinGroupEvent,
-
     GroupRecallEvent,
     FriendRecallEvent,
-
     GroupNameChangeEvent,
     GroupEntranceAnnouncementChangeEvent,
     GroupMuteAllEvent,
-
     GroupAllowAnonymousChatEvent,
     GroupAllowConfessTalkEvent,
     GroupAllowMemberInviteEvent,
-
     MemberJoinEvent,
     MemberLeaveEventKick,
     MemberLeaveEventQuit,
@@ -45,20 +31,28 @@ from .event.mirai import (
     MemberPermissionChangeEvent,
     MemberMuteEvent,
     MemberUnmuteEvent,
-
     NewFriendRequestEvent,
     MemberJoinRequestEvent,
-    BotInvitedJoinGroupRequestEvent
+    BotInvitedJoinGroupRequestEvent,
 )
 from .message.elements.internal import (
-    Plain, Source, Quote, At, AtAll, Face, Image, FlashImage,
-    Xml, Json, App, Poke, PokeMethods
+    Plain,
+    Source,
+    Quote,
+    At,
+    AtAll,
+    Face,
+    Image,
+    FlashImage,
+    Xml,
+    Json,
+    App,
+    Poke,
+    PokeMethods,
 )
 from .message.chain import MessageChain
 from .friend import Friend
-from .group import (
-    MemberPerm, Group, Member, MemberInfo, GroupConfig    
-)
+from .group import MemberPerm, Group, Member, MemberInfo, GroupConfig
 from .session import Session
 from .exceptions import (
     InvalidEventTypeDefinition,
@@ -73,5 +67,5 @@ from .exceptions import (
     NotSupportedVersion,
     DeprecatedImpl,
     EntangledSuperposition,
-    MissingNecessaryOne
-)
\ No newline at end of file
+    MissingNecessaryOne,
+)
