@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 import logging
 
+
 class AbstractLogger(ABC):
     @abstractmethod
     def info(self, msg):
@@ -22,11 +23,14 @@ class AbstractLogger(ABC):
     def exception(self, msg):
         pass
 
+
 class LoggingLogger(AbstractLogger):
     def __init__(self, **kwargs) -> None:
-        #logging.basicConfig(format='[%(asctime)s][%(levelname)s]: %(message)s', level=\
+        # logging.basicConfig(format='[%(asctime)s][%(levelname)s]: %(message)s', level=\
         #    logging.INFO if not kwargs.get("debug") else logging.DEBUG)
-        logging.basicConfig(format='[%(asctime)s][%(levelname)s]: %(message)s', level=logging.DEBUG)
+        logging.basicConfig(
+            format="[%(asctime)s][%(levelname)s]: %(message)s", level=logging.DEBUG
+        )
 
     def info(self, msg):
         return logging.info(msg)
@@ -41,4 +45,4 @@ class LoggingLogger(AbstractLogger):
         return logging.warn(msg)
 
     def exception(self, msg):
-        return logging.exception(msg)
\ No newline at end of file
+        return logging.exception(msg)
