@@ -21,7 +21,6 @@ from .elements import ExternalElement, InternalElement, Element
 import regex
 import copy
 
-T = TypeVar("T", bound=Type[Element])
 MessageIndex = Tuple[int, Optional[int]]
 
 
@@ -100,10 +99,10 @@ class MessageChain(BaseModel):
             ```
     """
 
-    __root__: Union[List[T], Tuple[T]]
+    __root__: Sequence[Element]
 
     @classmethod
-    def create(cls, elements: Sequence[T]) -> "MessageChain":
+    def create(cls, elements: Sequence[Element]) -> "MessageChain":
         """从传入的序列(可以是元组 tuple, 也可以是列表 list) 创建消息链.
 
         Args:
@@ -115,7 +114,7 @@ class MessageChain(BaseModel):
         return cls(__root__=elements)
 
     @classmethod
-    def parse_obj(cls: Type["MessageChain"], obj: List[T]) -> "MessageChain":
+    def parse_obj(cls: Type["MessageChain"], obj: List[Element]) -> "MessageChain":
         """内部接口, 会自动将作为外部态的消息元素转为内部态.
 
         Args:
@@ -232,7 +231,7 @@ class MessageChain(BaseModel):
                 result.append(i)
         return MessageChain(__root__=tuple(result))
 
-    def has(self, element_class: T) -> bool:
+    def has(self, element_class: Element) -> bool:
         """判断消息链中是否含有特定类型的消息元素
 
         Args:
@@ -243,7 +242,7 @@ class MessageChain(BaseModel):
         """
         return element_class in [type(i) for i in self.__root__]
 
-    def get(self, element_class: T) -> List[T]:
+    def get(self, element_class: Element) -> List[Element]:
         """获取消息链中所有特定类型的消息元素
 
         Args:
@@ -254,7 +253,7 @@ class MessageChain(BaseModel):
         """
         return [i for i in self.__root__ if type(i) is element_class]
 
-    def getOne(self, element_class: T, index: int) -> T:
+    def getOne(self, element_class: Element, index: int) -> Element:
         """获取消息链中第 index + 1 个特定类型的消息元素
 
         Args:
@@ -266,7 +265,7 @@ class MessageChain(BaseModel):
         """
         return self.get(element_class)[index]
 
-    def getFirst(self, element_class: T) -> T:
+    def getFirst(self, element_class: Element) -> Element:
         """获取消息链中第 1 个特定类型的消息元素
 
         Args:
@@ -292,7 +291,7 @@ class MessageChain(BaseModel):
         Returns:
             MessageChain: 拼接结果
         """
-        return cls.create(sum([i.__root__ for i in chains], []))
+        return cls.create(sum([list(i.__root__) for i in chains], []))
 
     def plusWith(self, *chains: "MessageChain") -> "MessageChain":
         """在现有的基础上将另一消息链拼接到原来实例的尾部, 并生成, 返回新的实例.
@@ -300,7 +299,7 @@ class MessageChain(BaseModel):
         Returns:
             MessageChain: 拼接结果
         """
-        return self.create(sum([i.__root__ for i in chains], self.__root__))
+        return self.create(sum([list(i.__root__) for i in chains], self.__root__))
 
     def plus(self, *chains: "MessageChain") -> NoReturn:
         """在现有的基础上将另一消息链拼接到原来实例的尾部
@@ -314,7 +313,7 @@ class MessageChain(BaseModel):
         if self.isImmutable:
             raise ValueError("this chain is not mutable")
         for i in chains:
-            self.__root__.extend(i.__root__)
+            self.__root__.extend(list(i.__root__))
 
     __contains__ = has
 
