@@ -70,7 +70,7 @@ class Quote(InternalElement, ExternalElement):
     targetId: int
     origin: "MessageChain"
 
-    @validator("origin", pre=True)
+    @validator("origin", pre=True, allow_reuse=True)
     def _(cls, v):
         from ..chain import MessageChain
 
@@ -327,7 +327,7 @@ class Image(InternalElement):
     path: Optional[str] = None
     type: Optional[ImageType]
 
-    @validator("type", always=True)
+    @validator("type", always=True, allow_reuse=True)
     def _(cls, v, values) -> ImageType:
         if v:
             return v
@@ -528,6 +528,9 @@ class Voice_LocalFile(ShadowElement, InternalElement, ExternalElement):
     def __init__(self, filepath: Path, method: Optional[UploadMethods] = None) -> None:
         super().__init__(filepath=filepath, method=method)
 
+    def fromExternal(cls, external_element) -> "InternalElement":
+        return external_element
+
     async def toExternal(self):
         app = application.get()
         try:
@@ -538,7 +541,7 @@ class Voice_LocalFile(ShadowElement, InternalElement, ExternalElement):
             )
 
         return await app.uploadVoice(
-            self, self.filepath.read_bytes(), methodd, return_external=True
+            self.filepath.read_bytes(), methodd, return_external=True
         )
 
     async def getReal(self, method: UploadMethods) -> "Image":
@@ -579,7 +582,7 @@ class Voice(InternalElement):
     def asDisplay(self) -> str:
         return "[语音]"
 
-    @validator("type", always=True)
+    @validator("type", always=True, allow_reuse=True)
     def _(cls, v, values) -> VoiceUploadType:
         if v:
             return v
